

# ZETUP |  Zimmermann's Extensible Tools for Unified Projects



[![](http://www.gnu.org/graphics/lgplv3-88x31.png)](
  https://gnu.org/licenses/lgpl.html)
[![](https://img.shields.io/pypi/pyversions/zetup?label=Python)](
  https://python.org)
[![](https://img.shields.io/pypi/v/zetup?label=PyPI)](
  https://pypi.python.org/pypi/zetup)
[![](https://img.shields.io/pypi/dd/zetup?label=Downloads)](
  https://pypi.python.org/pypi/zetup)



[![Linux build status](
  https://img.shields.io/travis/zimmermanncode/zetup/master?label=Linux%20build)](
  https://travis-ci.org/zimmermanncode/zetup)
[![Windows build status](
  https://img.shields.io/appveyor/ci/zimmermanncode/zetup/master?label=Windows%20build)](
  https://ci.appveyor.com/project/zimmermanncode/zetup)



[![Open Hub project](
  http://www.openhub.net/p/python-zetup/widgets/project_thin_badge.gif)](
  https://www.openhub.net/p/python-zetup)



**Hg** repository: https://bitbucket.org/zimmermanncode/zetup

**Git** mirror repositories:

* https://github.com/zimmermanncode/zetup
* https://gitlab.com/zimmermanncode/zetup


